@@ -2,13 +2,14 @@
 """
     pip_services3_commons.convert.JsonConverter
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    
+
     Json conversion utilities
-    
+
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
 
+import re
 import json
 from datetime import datetime
 from typing import Any, Optional
@@ -25,7 +26,7 @@ class JsonConverter:
     Example:
 
     .. code-block:: python
-    
+
         value1 = JsonConverter.from_json("{\"key\":123}") // Result: { key: 123 }
         value2 = JsonConverter.to_map({ key: 123}) // Result: "{\"key\":123}"
     """
@@ -44,7 +45,7 @@ class JsonConverter:
         if value is None:
             return None
 
-        value = json.loads(value)
+        value = json.loads(value, object_hook=JsonConverter.__from_json)
         return TypeConverter.to_type(typ, value)
 
     @staticmethod
@@ -61,9 +62,65 @@ class JsonConverter:
 
         if isinstance(value, datetime):
             str_time = value.strftime("%Y-%m-%dT%H:%M:%S.%f%z")
-            return (str_time[:-8] + str_time[-5:]).split('+')[0] + 'Z'  # Remove microseconds
+            return (str_time).split('+')[0] + 'Z'  # Remove microseconds
 
-        return json.dumps(value)
+        return json.dumps(value, default=JsonConverter.__to_json)
+
+    @staticmethod
+    def __from_json(obj):
+        for k, v in obj.items():
+            if isinstance(obj[k], list):
+                index = 0
+                for el in obj[k]:
+                    obj[k][index] = JsonConverter.__from_json(el)
+                    index += 1
+
+            elif isinstance(obj[k], str) and re.match(
+                    r"\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z)?", obj[k]):
+
+                if obj[k][-1].lower() == 'z':
+                    obj[k] = obj[k][:-1]
+                obj[k] = datetime.strptime(obj[k], "%Y-%m-%dT%H:%M:%S.%f")
+
+        return obj
+
+    @staticmethod
+    def __to_json(obj):
+        if obj is None:
+            return None
+
+        if isinstance(obj, set):
+            obj = list(obj)
+        if isinstance(obj, list):
+            result = []
+            for item in obj:
+                item = JsonConverter.__to_json(item)
+                result.append(item)
+            return result
+
+        if isinstance(obj, dict):
+            result = {}
+            for (k, v) in obj.items():
+                v = JsonConverter.__to_json(v)
+                result[k] = v
+            return result
+
+        if isinstance(obj, datetime):
+            return JsonConverter.to_json(obj)
+
+        if hasattr(obj, 'to_json'):
+            return obj.to_json()
+        if hasattr(obj, '__dict__'):
+            attribs = dict(obj.__dict__)
+            dict_obj = {}
+
+            for key in attribs.keys():
+                if not (key.endswith('__') and key.startswith('__')):
+                    dict_obj[key] = attribs[key]
+
+            return JsonConverter.__to_json(dict_obj)
+
+        return obj
 
     @staticmethod
     def to_nullable_map(value: str) -> Any:
